use Test::More tests => 51;

use Env::Path;
use Scalar::Util qw( looks_like_number );
use App::Env;
use App::Env::CIAO;


# first ensure that ahelp isn't in the path so we don't get confused

if ( Env::Path->PATH->Whence('ahelp') )
{
    diag( "The CIAO environment is already loaded! Unload before running this test\n" );
    die();
}


# versions to test; try both string and numeric. note that to Perl
# '3.4' and 3.4 are the same, but '4.0' and 4.0 are not.
my %version = (
                '3.4'  => '3.4',
                '4.0'  => '4.0',
                 4.0   => '4.0',
	        '4.1'  => '4.1',
		 4.1   => '4.1',
	        '4.2'  => '4.2',
		 4.2   => '4.2',
	        '4.3'  => '4.3',
		 4.3   => '4.3',
               );

# set default
$version{default} = App::Env::CIAO::VLATEST;

# CIAO X
$version{X} = $version{4.3};

my $env;


for my $version ( keys %version )
{
    test_version( 'CIAO', $version );
    test_version( 'ciao', $version );
}

# test ciao34 alias
{
  local $version{default} = $version{'3.4'};
  test_version( 'ciao34', 'default' );
}

sub test_version
{
    my ( $app, $version ) = @_;

    eval {
        $env = App::Env->new( $app,
                            { Cache => 0,
                              AppOpts => { $version eq 'default' ? () : ( Version => $version ) }
                            } );
    };
    my $err = $@;

    my $skip = 0;
    if ( $err )
    {
        $skip = 1;

        # some platforms don't support all versions; not an error, really
        if ( $err =~ /no ciao configuration/i )
        {
            diag( "There is no $app configuration for this OS and $app version $version\n" );
        }

        # some hosts don't have things mounted correctly
        elsif ( $err =~ /does not exist on this system/i )
        {
            diag( "This host is not set up for $app version $version\n" );
        }

        else
        {
            $fatal = 1;
        }
    }

  SKIP: {
        skip "platform error", 3 if $skip;

        ok( ! $fatal, "$app $version: load" )
          or diag($@);

        skip "load error", 2 if $fatal;

        ok( $env->system( 'ahelp dmcoords > /dev/null' ) == 0, "$app $version: run" );

	# check version
	my $ASCDS_INSTALL = $env->env('ASCDS_INSTALL');
	skip 'No ASCDS_INSTALL environment variable', 1 unless $ASCDS_INSTALL;

	my $verfile = $ASCDS_INSTALL . '/VERSION';
	skip "Can't access $verfile\n", 1 unless -e $verfile && -r _;

	if ( open VERSION, '<', $verfile )
        {
            ( my $vstr ) = <VERSION> =~ /^CIAO\s+(\d.\d)/;
            fail( "error parsing version in $verfile\n" )
              if ! defined $vstr;

            close VERSION;

            is( $vstr, $version{$version}, "$app $version: version check" );
        }
        else
        {
            fail( "errer opening $verfile\n" );
        }

    }

}
